@@ -607,19 +607,24 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                             (4, 4) if self.inputs.space in STANDARD_SPACES else (2, 2)
                         )
 
-                    if curr_codes != xcodes or curr_units != units:
+                    curr_zooms = zooms = hdr.get_zooms()
+                    if "RepetitionTime" in self.inputs.get():
+                        zooms = curr_zooms[:3] + (self.inputs.RepetitionTime,)
+
+                    if (curr_codes, curr_units, curr_zooms) != (xcodes, units, zooms):
                         self._results["fixed_hdr"][i] = True
                         new_header = hdr.copy()
                         new_header.set_qform(nii.affine, xcodes[0])
                         new_header.set_sform(nii.affine, xcodes[1])
                         new_header.set_xyzt_units(*units)
+                        new_header.set_zooms(zooms)
 
                 if data_dtype == "source":  # match source dtype
                     try:
-                        data_dtype = nb.load(self.inputs.source_file).get_data_dtype()
+                        data_dtype = nb.load(self.inputs.source_file[0]).get_data_dtype()
                     except Exception:
                         LOGGER.warning(
-                            f"Could not get data type of file {self.inputs.source_file}"
+                            f"Could not get data type of file {self.inputs.source_file[0]}"
                         )
                         data_dtype = None
 
@@ -648,6 +653,10 @@ space-MNI152NLin6Asym_desc-preproc_bold.json'
                 if new_data is None:
                     set_consumables(new_header, orig_img.dataobj)
                     new_data = orig_img.dataobj.get_unscaled()
+                else:
+                    # Without this, we would be writing nans
+                    # This is our punishment for hacking around nibabel defaults
+                    new_header.set_slope_inter(slope=1., inter=0.)
                 unsafe_write_nifti_header_and_data(
                     fname=out_file,
                     header=new_header,
